@@ -1,12 +1,16 @@
+from .search import BaseSearch
 from .search import GridSearch
 from .search import RandomSearch
+from .search_cv import BaseSearchCV
 from .search_cv import GridSearchCV
 from .search_cv import RandomSearchCV
 
 
 __all__ = [
+    "BaseSearch",
     "GridSearch",
     "RandomSearch",
+    "BaseSearchCV",
     "GridSearchCV",
     "RandomSearchCV"
 ]
